@@ -23,13 +23,15 @@
 #  Imports:
 #-------------------------------------------------------------------------
 
-
+from __future__ import absolute_import
 
 from operator import itemgetter
 
 from traits.api import BaseTraitHandler, CTrait, Enum, TraitError
 
 from .ui_traits import SequenceTypes
+import six
+
 
 #-------------------------------------------------------------------------
 #  Trait definitions:
@@ -82,12 +84,12 @@ def commatize(value):
 #-------------------------------------------------------------------------
 
 
-def enum_values_changed(values, strfunc=str):
+def enum_values_changed(values, strfunc=six.text_type):
     """ Recomputes the mappings for a new set of enumeration values.
     """
 
     if isinstance(values, dict):
-        data = [(strfunc(v), n) for n, v in list(values.items())]
+        data = [(strfunc(v), n) for n, v in values.items()]
         if len(data) > 0:
             data.sort(key=itemgetter(0))
             col = data[0][0].find(':') + 1
@@ -100,7 +102,7 @@ def enum_values_changed(values, strfunc=str):
         if not isinstance(handler, BaseTraitHandler):
             raise TraitError("Invalid value for 'values' specified")
         if handler.is_mapped:
-            data = [(strfunc(n), n) for n in list(handler.map.keys())]
+            data = [(strfunc(n), n) for n in handler.map.keys()]
             data.sort(key=itemgetter(0))
         else:
             data = [(strfunc(v), v) for v in handler.values]
