@@ -22,7 +22,7 @@
 #  Imports:
 #-------------------------------------------------------------------------
 
-
+from __future__ import absolute_import
 
 import inspect
 from operator import itemgetter
@@ -34,6 +34,7 @@ from traits.api import Any, Bool, HasPrivateTraits, HasTraits, Instance, List, S
 from .tree_node import ObjectTreeNode, TreeNode, TreeNodeObject
 
 from .editors.tree_editor import TreeEditor
+import six
 
 #-------------------------------------------------------------------------
 #  'SingleValueTreeNodeObject' class:
@@ -445,7 +446,7 @@ class DictNode(TupleNode):
         """ Gets the object's children.
         """
         node_for = self.node_for
-        items = [(repr(k), v) for k, v in list(self.value.items())]
+        items = [(repr(k), v) for k, v in self.value.items()]
         items.sort(key=itemgetter(0))
         if len(items) > 500:
             return ([node_for('[%s]' % k, v) for k, v in items[: 250]] +
@@ -479,7 +480,7 @@ class FunctionNode(SingleValueTreeNodeObject):
     def format_value(self, value):
         """ Returns the formatted version of the value.
         """
-        return 'Function %s()' % (value.__code__.co_name)
+        return 'Function %s()' % (value.__name__)
 
 #---------------------------------------------------------------------------
 #  'MethodNode' class:
@@ -502,7 +503,7 @@ class MethodNode(MultiValueTreeNodeObject):
         return '%sound method %s.%s()' % (
             type,
             value.__self__.__class__.__name__,
-            value.__func__.__code__.co_name)
+            value.__func__.__name__)
 
     #-------------------------------------------------------------------------
     #  Returns whether or not the object has children:
@@ -563,7 +564,7 @@ class ObjectNode(MultiValueTreeNodeObject):
     def tno_get_children(self, node):
         """ Gets the object's children.
         """
-        items = [(k, v) for k, v in list(self.value.__dict__.items())]
+        items = [(k, v) for k, v in self.value.__dict__.items()]
         items.sort(key=itemgetter(0))
         return [self.node_for('.' + k, v) for k, v in items]
 
@@ -634,7 +635,7 @@ class TraitsNode(ObjectNode):
         names = {}
         for name in value.trait_names(type=lambda x: x != 'event'):
             names[name] = None
-        for name in list(value.__dict__.keys()):
+        for name in value.__dict__.keys():
             names[name] = None
         return list(names.keys())
 
@@ -707,7 +708,7 @@ def basic_types():
         _basic_types = [
             (type(None), NoneNode),
             (str, StringNode),
-            (str, StringNode),
+            (six.text_type, StringNode),
             (bool, BoolNode),
             (int, IntNode),
             (float, FloatNode),
